aboutsummaryrefslogtreecommitdiffstats
path: root/boot.php
diff options
context:
space:
mode:
authorfriendica <info@friendica.com>2012-10-28 18:50:35 -0700
committerfriendica <info@friendica.com>2012-10-28 18:50:35 -0700
commit4bcf19632bc5158095a5d2d5d63dea1b25b146b7 (patch)
tree362ccfbd661b779bd864fa6c7416c9a7b1c15069 /boot.php
parent1a9ab127482ee4eb17e3d2bd0ffa222f7053715b (diff)
downloadvolse-hubzilla-4bcf19632bc5158095a5d2d5d63dea1b25b146b7.tar.gz
volse-hubzilla-4bcf19632bc5158095a5d2d5d63dea1b25b146b7.tar.bz2
volse-hubzilla-4bcf19632bc5158095a5d2d5d63dea1b25b146b7.zip
Now have a solid permissions model. Create a few functions to enumerate them and then we're off to the races.
Diffstat (limited to 'boot.php')
-rw-r--r--boot.php27
1 files changed, 22 insertions, 5 deletions
diff --git a/boot.php b/boot.php
index 10f1cddc7..d7b51867f 100644
--- a/boot.php
+++ b/boot.php
@@ -8,6 +8,7 @@ require_once('include/datetime.php');
require_once('include/language.php');
require_once('include/nav.php');
require_once('include/cache.php');
+require_once('include/permissions.php');
require_once('library/Mobile_Detect/Mobile_Detect.php');
require_once('include/BaseObject.php');
@@ -182,6 +183,14 @@ define ( 'PERMS_CONTACTS' , 0x0008 );
define ( 'PERMS_SPECIFIC' , 0x0080 );
+// Address book flags
+
+define ( 'ABOOK_FLAG_BLOCKED' , 0x0001);
+define ( 'ABOOK_FLAG_IGNORED' , 0x0002);
+define ( 'ABOOK_FLAG_HIDDEN' , 0x0004);
+
+
+
/**
* Maximum number of "people who like (or don't like) this" that we will list by name
*/
@@ -394,11 +403,11 @@ if(! class_exists('App')) {
class App {
- public $account = null; // account record
-
- private $channel = null; // channel record
- private $observer = null; // xchan record
- private $widgets = array(); // widgets for this page
+ public $account = null; // account record
+ private $channel = null; // channel record
+ private $observer = null; // xchan record
+ private $perms = null; // observer permissions
+ private $widgets = array(); // widgets for this page
@@ -654,6 +663,14 @@ if(! class_exists('App')) {
return $this->observer;
}
+ function set_perms($perms) {
+ $this->perms = $perms;
+ }
+
+ function get_perms() {
+ return $this->perms;
+ }
+
function get_apps() {
return $this->apps;
}